Context

Struct Context 

pub struct Context { /* private fields */ }
Implementation of crate::Spawner, crate::Clock, crate::Network, and crate::Storage for the deterministic runtime.

Implementations

Source

impl Context

pub fn auditor(&self) -> Arc<Auditor>

Get a reference to the Auditor.

pub fn storage_audit(&self) -> [u8; 32]

Compute a Sha256 digest of all storage contents.

pub fn storage_fault_config(&self) -> Arc<RwLock<FaultConfig>>

Access the storage fault configuration.

Changes to the returned FaultConfig take effect immediately for subsequent storage operations. This allows dynamically enabling or disabling fault injection during a test.

pub fn resolver_register( &self, host: impl Into<String>, addrs: Option<Vec<IpAddr>>, )

Register a DNS mapping for a hostname.

If addrs is None, the mapping is removed. If addrs is Some, the mapping is added or updated.