pub struct WriteConfig {
pub failure_rate: Probability,
pub retention_rate: Probability,
pub mode: PartialWriteMode,
}Expand description
Fault configuration for write_at operations and byte retention from failed writes or
successful unsynchronized writes when a crash is simulated.
Fields
failure_rate: ProbabilityProbability that write_at returns an injected failure.
retention_rate: ProbabilityProbability used by the selected mode when retaining submitted bytes.
mode: PartialWriteModeArrangement of bytes retained by the simulated storage device.