IoBufsMut

Struct IoBufsMut 

pub struct IoBufsMut { /* private fields */ }
Container for one or more mutable buffers.

Implementations

Source

impl IoBufsMut

pub const fn as_single(&self) -> Option<&IoBufMut>

Returns a reference to the single contiguous buffer, if present.

Returns Some only when this is currently represented as one chunk.

pub const fn as_single_mut(&mut self) -> Option<&mut IoBufMut>

Returns a mutable reference to the single contiguous buffer, if present.

Returns Some only when this is currently represented as one chunk.

pub fn try_into_single(self) -> Result<IoBufMut, Self>

Consume this container and return the single buffer if present.

Returns Ok(IoBufMut) only when readable data is represented as one chunk. Returns Err(Self) with the original container otherwise.

pub fn len(&self) -> usize

Number of bytes remaining across all buffers.

pub fn is_empty(&self) -> bool

Whether all buffers are empty.

pub const fn is_single(&self) -> bool

Whether this contains a single contiguous buffer.

When true, chunk() returns all remaining bytes.

pub fn freeze(self) -> IoBufs

Freeze into immutable IoBufs.

pub fn coalesce(self) -> IoBufMut

Coalesce all buffers into a single contiguous IoBufMut.

Zero-copy if only one buffer. Copies if multiple buffers.

pub fn coalesce_with_pool(self, pool: &BufferPool) -> IoBufMut

Coalesce all buffers into a single contiguous IoBufMut, using the pool for allocation if multiple buffers need to be merged.

Zero-copy if only one buffer. Uses pool allocation if multiple buffers.

pub fn coalesce_with_pool_extra( self, pool: &BufferPool, extra: usize, ) -> IoBufMut

Coalesce all buffers into a single contiguous IoBufMut with extra capacity, using the pool for allocation.

Zero-copy if single buffer with sufficient spare capacity.

pub fn capacity(&self) -> usize

Returns the total capacity across all buffers.

pub fn copy_from_slice(&mut self, src: &[u8])

Copy data from a slice into the buffers.

Panics if the slice length doesn’t match the total buffer length.