pub async fn drive_pending_syncs<T>(
pending: &PendingSyncs,
fut: impl Future<Output = T>,
) -> TExpand description
Drive fut to completion, releasing any parked syncs each time it stalls.
pub async fn drive_pending_syncs<T>(
pending: &PendingSyncs,
fut: impl Future<Output = T>,
) -> TDrive fut to completion, releasing any parked syncs each time it stalls.