pub struct DelayedSyncBlob<B> { /* private fields */ }Expand description
Blob wrapper that parks each started sync and supports one-shot blocking sync tracking.
Implementations
Sourceimpl<B> DelayedSyncBlob<B>
impl<B> DelayedSyncBlob<B>
Sourcepub fn new(inner: B) -> (Self, PendingSyncs)
pub fn new(inner: B) -> (Self, PendingSyncs)
Wrap inner, returning the blob and the list its deferred syncs are pushed onto.