pub struct DelayedSyncContext<E> {
pub inner: E,
pub pending: PendingSyncs,
}Expand description
Context wrapper whose blobs defer Blob::start_sync and can gate blocking syncs in tests.
Fields
inner: Epending: PendingSyncsTrait Implementations
Sourceimpl<E: BufferPooler> BufferPooler for DelayedSyncContext<E>
impl<E: BufferPooler> BufferPooler for DelayedSyncContext<E>
Sourcefn network_buffer_pool(&self) -> &BufferPool
fn network_buffer_pool(&self) -> &BufferPool
Returns the network BufferPool.
Sourcefn storage_buffer_pool(&self) -> &BufferPool
fn storage_buffer_pool(&self) -> &BufferPool
Returns the storage BufferPool.
Sourceimpl<E: Clock> Clock for DelayedSyncContext<E>
impl<E: Clock> Clock for DelayedSyncContext<E>
Sourcefn current(&self) -> SystemTime
fn current(&self) -> SystemTime
Returns the current time.
Sourcefn sleep(&self, duration: Duration) -> impl Future<Output = ()> + Send + 'static
fn sleep(&self, duration: Duration) -> impl Future<Output = ()> + Send + 'static
Sleep for the given duration.
Sourcefn sleep_until(
&self,
deadline: SystemTime,
) -> impl Future<Output = ()> + Send + 'static
fn sleep_until( &self, deadline: SystemTime, ) -> impl Future<Output = ()> + Send + 'static
Sleep until the given deadline.
Sourceimpl<E: Clock> Clock for DelayedSyncContext<E>
impl<E: Clock> Clock for DelayedSyncContext<E>
Sourceimpl<E: Clone> Clone for DelayedSyncContext<E>
impl<E: Clone> Clone for DelayedSyncContext<E>
Sourcefn clone(&self) -> DelayedSyncContext<E>
fn clone(&self) -> DelayedSyncContext<E>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<E: Metrics> Metrics for DelayedSyncContext<E>
impl<E: Metrics> Metrics for DelayedSyncContext<E>
Sourceimpl<E: Clock> ReasonablyRealtime for DelayedSyncContext<E>
impl<E: Clock> ReasonablyRealtime for DelayedSyncContext<E>
Sourcefn reference_point(&self) -> Self::Instant
fn reference_point(&self) -> Self::Instant
Returns a reference point at the start of an operation.
Sourceimpl<E: Spawner> Spawner for DelayedSyncContext<E>
impl<E: Spawner> Spawner for DelayedSyncContext<E>
Sourcefn spawn<F, Fut, T>(self, f: F) -> Handle<T> ⓘ
fn spawn<F, Fut, T>(self, f: F) -> Handle<T> ⓘ
Spawn a task with the current context. Read more
Sourceasync fn stop(self, value: i32, timeout: Option<Duration>) -> Result<(), Error>
async fn stop(self, value: i32, timeout: Option<Duration>) -> Result<(), Error>
Signals the runtime to stop execution and waits for all outstanding tasks
to perform any required cleanup and exit. Read more
Sourcefn stopped(&self) -> Signal ⓘ
fn stopped(&self) -> Signal ⓘ
Returns an instance of a signal::Signal that resolves when Spawner::stop is called by
any task. Read more
Sourceimpl<E: Storage> Storage for DelayedSyncContext<E>
impl<E: Storage> Storage for DelayedSyncContext<E>
Sourcetype Blob = DelayedSyncBlob<<E as Storage>::Blob>
type Blob = DelayedSyncBlob<<E as Storage>::Blob>
The readable/writeable storage buffer that can be opened by this Storage.
Sourceasync fn open_versioned(
&self,
partition: &str,
name: &[u8],
versions: RangeInclusive<u16>,
) -> Result<(Self::Blob, u64, u16), Error>
async fn open_versioned( &self, partition: &str, name: &[u8], versions: RangeInclusive<u16>, ) -> Result<(Self::Blob, u64, u16), Error>
Open an existing blob in a given partition or create a new one, returning
the blob and its length. Read more
Sourceasync fn remove(
&self,
partition: &str,
name: Option<&[u8]>,
) -> Result<(), Error>
async fn remove( &self, partition: &str, name: Option<&[u8]>, ) -> Result<(), Error>
Remove a blob from a given partition. Read more
Sourceimpl<E: Supervisor> Supervisor for DelayedSyncContext<E>
impl<E: Supervisor> Supervisor for DelayedSyncContext<E>
impl<E: TryCryptoRng> TryCryptoRng for DelayedSyncContext<E>
Sourceimpl<E: TryRng> TryRng for DelayedSyncContext<E>
impl<E: TryRng> TryRng for DelayedSyncContext<E>