HistogramExt

Trait HistogramExt 

pub trait HistogramExt {
    // Required method
    fn observe_between(&self, start: SystemTime, end: SystemTime);
}
Convenience methods for Prometheus histograms.

Required Methods

fn observe_between(&self, start: SystemTime, end: SystemTime)

Observe the duration between two points in time, in seconds.

If the clock goes backwards, the duration is 0.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors