pub struct Gauge<N = i64, A = Atomic<i64>> { /* private fields */ }Expand description
Open Metrics Gauge to record current measurements.
Single increasing, decreasing or constant value metric.
Gauge is generic over the actual data type tracking the Gauge state
as well as the data type used to interact with the Gauge. Out of
convenience the generic type parameters are set to use an AtomicI64 as a
storage and i64 on the interface by default.
Examples
Using AtomicI64 as storage and i64 on the interface
let gauge: Gauge = Gauge::default();
gauge.set(42);
let _value = gauge.get();Using AtomicU64 as storage and f64 on the interface
let gauge = Gauge::<f64, AtomicU64>::default();
gauge.set(42.0);
let _value: f64 = gauge.get();Implementations