pub struct Registered<M> { /* private fields */ }Expand description
A metric handle whose lifetime controls registry exposure and attached cleanup.
Implementations
Sourceimpl<M> Registered<M>
impl<M> Registered<M>
Sourcepub fn with_registration(metric: M, registration: Registration) -> Self
pub fn with_registration(metric: M, registration: Registration) -> Self
Create a metric handle with an explicit lifecycle registration.
The provided Registration controls what happens when the last clone
of this handle is dropped. Use Registration::from with () for a
raw handle that is not exposed by a runtime registry.
pub fn metric(&self) -> &M