pub struct Registration { /* private fields */ }Expand description
A shared lifecycle token for a Registered metric handle.
When the last clone of the associated Registered
handle is dropped, this registration is dropped as well. Runtime-managed
metrics use that drop to unregister themselves from the runtime registry,
while external callers may attach custom cleanup with Registration::from.
Implementations
Sourceimpl Registration
impl Registration
Sourcepub fn from<G>(guard: G) -> Selfwhere
G: Send + 'static,
pub fn from<G>(guard: G) -> Selfwhere
G: Send + 'static,
Create a registration from a guard that should be dropped when the last
associated Registered handle is dropped.