Utility functions for interacting with any runtime.
Modules
- buffer
- Buffers for reading and writing to crate::Blobs.
- signal
- Mechanisms for coordinating actions across many tasks.
Structs
- Blocker
- Synchronization primitive that enables a thread to block until a waker delivers a signal.
- Handle
- Handle to a spawned task.
Enums
- Context
Cell - A wrapper around context that allows it to be taken and returned without requiring
all interactions to unwrap (as with
Option<C>). - Execution
- The execution mode of a task.
Functions
- reschedule
- Yield control back to the runtime.