pub enum ContextCell<C> {
Present(C),
Missing,
}Expand description
A wrapper around context that allows it to be taken and returned without requiring
all interactions to unwrap (as with Option<C>).
Variants
Implementations
Sourceimpl<C> Cell<C>
impl<C> Cell<C>
Sourcepub fn restore(&mut self, context: C)
pub fn restore(&mut self, context: C)
Return a context to the slot, panicking if one is already present.
Sourcepub fn as_present(&self) -> &C
pub fn as_present(&self) -> &C
Sourcepub fn as_present_mut(&mut self) -> &mut C
pub fn as_present_mut(&mut self) -> &mut C
Sourcepub fn into_present(self) -> C
pub fn into_present(self) -> C