pub struct WriteOptions(/* private fields */);Expand description
Options that alter one Blob::write_at operation.
WriteOptions::default applies no options.
Combine options with |, such as WriteOptions::SYNC | WriteOptions::DONT_CACHE.
Implementations
Sourceimpl WriteOptions
impl WriteOptions
Sourcepub const SYNC: Self
pub const SYNC: Self
Durably persist the submitted bytes before returning.
This is not a durability barrier for earlier writes without
WriteOptions::SYNC or earlier Blob::resize calls.
Sourcepub const DONT_CACHE: Self
pub const DONT_CACHE: Self
Advise that the submitted bytes need not remain in the OS page cache.
This is a best-effort performance hint for callers that maintain their own cache. Implementations may ignore it. It does not change visibility or durability, or guarantee that the range is absent from the OS page cache.