Utilities for working with histograms.
Structs
- Buckets
- Holds constants for bucket sizes for histograms.
- Scoped
Timer - A timer guard that observes its duration when dropped.
- Timed
- A wrapper around a histogram that can time operations using a caller-provided clock.
- Timer
- A timer that records a duration when explicitly observed.
Traits
- Histogram
Ext - Convenience methods for Prometheus histograms.
Functions
- duration_
histogram - Register a duration histogram using
Buckets::LOCAL(storage-style work).