Module utils

Module utils 

Utility functions for interacting with any runtime.

Modules

buffer
Buffers for reading and writing to crate::Blobs.
signal
Mechanisms for coordinating actions across many tasks.

Structs

Blocker
Synchronization primitive that enables a thread to block until a waker delivers a signal.
Handle
Handle to a spawned task.
MetricEncoder
A writer that groups metrics by family name and deduplicates HELP/TYPE metadata during Prometheus encoding.

Enums

ContextCell
A wrapper around context that allows it to be taken and returned without requiring all interactions to unwrap (as with Option<C>).
Execution
The execution mode of a task.

Functions

add_attribute
Add an attribute to a sorted attribute list, maintaining sorted order via binary search.
reschedule
Yield control back to the runtime.
validate_label
Validates that a label matches Prometheus metric name format: [a-zA-Z][a-zA-Z0-9_]*.