pub struct CacheRef { /* private fields */ }Expand description
A reference to a page cache that can be shared across threads via cloning, along with the page size that will be used with it. Provides the API for interacting with the page cache in a thread-safe manner.
Implementations
Sourceimpl CacheRef
impl CacheRef
Sourcepub fn new(
pool: BufferPool,
page_size: NonZeroU16,
capacity: NonZeroUsize,
) -> Self
pub fn new( pool: BufferPool, page_size: NonZeroU16, capacity: NonZeroUsize, ) -> Self
Create a shared page-cache handle backed by pool.
The cache stores at most capacity pages, each exactly page_size bytes.
Initialization eagerly allocates and zeroes all cache slots from pool.
Sourcepub fn from_pooler(
pooler: &impl BufferPooler,
page_size: NonZeroU16,
capacity: NonZeroUsize,
) -> Self
pub fn from_pooler( pooler: &impl BufferPooler, page_size: NonZeroU16, capacity: NonZeroUsize, ) -> Self
Create a shared page-cache handle, extracting the storage BufferPool from a BufferPooler.
Sourcepub const fn pool(&self) -> &BufferPool
pub const fn pool(&self) -> &BufferPool
Returns the storage buffer pool associated with this cache.
Sourcepub fn next_id(&self) -> u64
pub fn next_id(&self) -> u64
Returns a unique id for the next blob that will use this page cache.
Sourcepub const fn offset_to_page(&self, offset: u64) -> (u64, u64)
pub const fn offset_to_page(&self, offset: u64) -> (u64, u64)
Convert a logical offset into the number of the page it belongs to and the offset within that page.
Sourcepub fn cache(&self, blob_id: u64, buf: &[u8], offset: u64) -> usize
pub fn cache(&self, blob_id: u64, buf: &[u8], offset: u64) -> usize
Cache the provided pages of data in the page cache, returning the remaining bytes that
didn’t fill a whole page. offset must be page aligned.
Panics
- Panics if
offsetis not page aligned. - If the buffer is not the size of a page.